@@ -1,34 +1,90 @@
 --
 -- move objects from pg_catalog and from public schema to schema oracle
 --
-ALTER FUNCTION pg_catalog.trunc(date,text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.round(date,text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.next_day(date,text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.next_day(date,integer) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.last_day(date) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.months_between(date,date) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.add_months(date,integer) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.trunc(timestamp with time zone,text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.round(timestamp with time zone,text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.round(timestamp with time zone) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.round(date) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.trunc(timestamp with time zone) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.trunc(date) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.nlssort(text,text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.nlssort(text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.set_nls_sort(text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.instr(text,text,integer,integer) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.instr(text,text,integer) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.instr(text,text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.to_char(smallint) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.to_char(integer) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.to_char(bigint) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.to_char(real) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.to_char(double precision) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.to_char(numeric) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.to_number(text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.to_number(numeric) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.to_number(numeric,numeric) SET SCHEMA oracle;
+
+DO $$
+BEGIN
+  IF EXISTS(SELECT * FROM pg_settings WHERE name = 'server_version_num' AND setting::int >= 120000) THEN
+    ALTER FUNCTION pg_catalog.trunc(date,text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.round(date,text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.next_day(date,text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.next_day(date,integer) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.last_day(date) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.months_between(date,date) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.add_months(date,integer) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.trunc(timestamp with time zone,text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.round(timestamp with time zone,text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.round(timestamp with time zone) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.round(date) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.trunc(timestamp with time zone) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.trunc(date) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.nlssort(text,text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.nlssort(text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.set_nls_sort(text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.instr(text,text,integer,integer) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.instr(text,text,integer) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.instr(text,text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.to_char(smallint) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.to_char(integer) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.to_char(bigint) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.to_char(real) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.to_char(double precision) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.to_char(numeric) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.to_number(text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.to_number(numeric) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.to_number(numeric,numeric) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.lnnvl(boolean) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.listagg1_transfn(internal,text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.wm_concat_transfn(internal,text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.listagg2_transfn(internal,text,text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.listagg_finalfn(internal) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.listagg(text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.wm_concat(text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.listagg(text,text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.median4_transfn(internal,real) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.median4_finalfn(internal) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.median8_transfn(internal,double precision) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.median8_finalfn(internal) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.median(real) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.median(double precision) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.substrb(varchar2,integer,integer) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.substrb(varchar2,integer) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.lengthb(varchar2) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.strposb(varchar2,varchar2) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.trunc(timestamp without time zone,text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.round(timestamp without time zone,text) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.round(timestamp without time zone) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.trunc(timestamp without time zone) SET SCHEMA oracle;
+    ALTER FUNCTION pg_catalog.to_date(text) RENAME TO orafce__obsolete_to_date;
+    ALTER FUNCTION pg_catalog.orafce__obsolete_to_date(text) SET SCHEMA oracle;
+  ELSE
+    -- Pre PostgreSQL 12 doesn't allow ALTER FUNCTION pg_catalog.xx SET SCHEMA
+    -- So we need to use dirty way
+    ALTER FUNCTION pg_catalog.to_date(text) RENAME TO orafce__obsolete_to_date;
+
+    INSERT INTO pg_depend
+      SELECT 'pg_proc'::regclass, oid, 0, 'pg_namespace'::regclass, 'oracle'::regnamespace, 0, 'n'
+          FROM pg_proc WHERE oid IN (SELECT objid
+                                       FROM pg_depend
+                                      WHERE refclassid = 'pg_extension'::regclass AND refobjid = (SELECT oid
+                                                                                                    FROM pg_extension
+                                                                                                   WHERE extname = 'orafce')
+                                        AND classid = 'pg_proc'::regclass)
+                         AND pronamespace = 'pg_catalog'::regnamespace;
+
+    UPDATE pg_proc
+       SET pronamespace = 'oracle'::regnamespace
+     WHERE oid  IN (SELECT objid
+                      FROM pg_depend
+                     WHERE refclassid = 'pg_extension'::regclass AND refobjid = (SELECT oid
+                                                                                   FROM pg_extension
+                                                                                  WHERE extname = 'orafce')
+                       AND classid = 'pg_proc'::regclass)
+      AND pronamespace = 'pg_catalog'::regnamespace;
+  END IF;
+END;
+$$;
+
 ALTER FUNCTION public.to_multi_byte(text) SET SCHEMA oracle;
 ALTER FUNCTION public.to_single_byte(text) SET SCHEMA oracle;
 ALTER FUNCTION public.bitand(bigint,bigint) SET SCHEMA oracle;
@@ -43,7 +99,6 @@ ALTER FUNCTION public.nanvl(double precision,character varying) SET SCHEMA oracl
 ALTER FUNCTION public.nanvl(numeric,character varying) SET SCHEMA oracle;
 ALTER FUNCTION public.dump("any") SET SCHEMA oracle;
 ALTER FUNCTION public.dump("any",integer) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.lnnvl(boolean) SET SCHEMA oracle;
 ALTER FUNCTION public.nvl(anyelement,anyelement) SET SCHEMA oracle;
 ALTER FUNCTION public.nvl2("any",anyelement,anyelement) SET SCHEMA oracle;
 ALTER FUNCTION public.nvl2("any",text,text) SET SCHEMA oracle;
@@ -103,19 +158,6 @@ ALTER FUNCTION public.decode(anyelement,anyelement,timestamp with time zone,anye
 ALTER FUNCTION public.decode(anyelement,anyelement,timestamp with time zone,anyelement,timestamp with time zone,anyelement,timestamp with time zone,timestamp with time zone) SET SCHEMA oracle;
 ALTER FUNCTION public.dump(text) SET SCHEMA oracle;
 ALTER FUNCTION public.dump(text,integer) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.listagg1_transfn(internal,text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.wm_concat_transfn(internal,text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.listagg2_transfn(internal,text,text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.listagg_finalfn(internal) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.listagg(text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.wm_concat(text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.listagg(text,text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.median4_transfn(internal,real) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.median4_finalfn(internal) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.median8_transfn(internal,double precision) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.median8_finalfn(internal) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.median(real) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.median(double precision) SET SCHEMA oracle;
 ALTER FUNCTION public.varchar2in(cstring,oid,integer) SET SCHEMA oracle;
 ALTER FUNCTION public.varchar2out(varchar2) SET SCHEMA oracle;
 ALTER FUNCTION public.varchar2_transform(internal) SET SCHEMA oracle;
@@ -124,10 +166,6 @@ ALTER FUNCTION public.varchar2send(varchar2) SET SCHEMA oracle;
 ALTER FUNCTION public.varchar2typmodin(cstring[]) SET SCHEMA oracle;
 ALTER FUNCTION public.varchar2typmodout(integer) SET SCHEMA oracle;
 ALTER FUNCTION public.varchar2(varchar2,integer,boolean) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.substrb(varchar2,integer,integer) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.substrb(varchar2,integer) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.lengthb(varchar2) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.strposb(varchar2,varchar2) SET SCHEMA oracle;
 ALTER FUNCTION public.nvarchar2in(cstring,oid,integer) SET SCHEMA oracle;
 ALTER FUNCTION public.nvarchar2out(nvarchar2) SET SCHEMA oracle;
 ALTER FUNCTION public.nvarchar2_transform(internal) SET SCHEMA oracle;
@@ -136,16 +174,10 @@ ALTER FUNCTION public.nvarchar2send(nvarchar2) SET SCHEMA oracle;
 ALTER FUNCTION public.nvarchar2typmodin(cstring[]) SET SCHEMA oracle;
 ALTER FUNCTION public.nvarchar2typmodout(integer) SET SCHEMA oracle;
 ALTER FUNCTION public.nvarchar2(nvarchar2,integer,boolean) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.trunc(timestamp without time zone,text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.round(timestamp without time zone,text) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.round(timestamp without time zone) SET SCHEMA oracle;
-ALTER FUNCTION pg_catalog.trunc(timestamp without time zone) SET SCHEMA oracle;
 
 ALTER TYPE public.nvarchar2 SET SCHEMA oracle;
 ALTER TYPE public.varchar2 SET SCHEMA oracle;
 
-ALTER FUNCTION pg_catalog.to_date(text) RENAME TO orafce__obsolete_to_date;
-ALTER FUNCTION pg_catalog.orafce__obsolete_to_date(text) SET SCHEMA oracle;
 
 ALTER VIEW public.dual SET SCHEMA oracle;
 
