@@ -164,6 +164,12 @@ SELECT REGEXP_INSTR('1234567890 1234567890 1234567890', '(123)(4(56)(78))', 1, -
 SELECT REGEXP_INSTR('1234567890 1234567890 1234567890', '(123)(4(56)(78))', 1, 3, -1, 'i', 4);
 SELECT REGEXP_INSTR('1234567890 1234567890 1234567890', '(123)(4(56)(78))', 1, 3, 1, 'i', -4);
 
+-- ORACLE> SELECT REGEXP_INSTR('123 123456 1234567, 1234567 1234567 12', '[^ ]+', 1, 6) FROM DUAL; -> 37
+SELECT REGEXP_INSTR('123 123456 1234567, 1234567 1234567 12', '[^ ]+', 1, 6) ;
+-- ORACLE> SELECT REGEXP_INSTR('123 123456 1234567, 1234567 1234567 12', '[^ ]+', 1, 6, 1) FROM DUAL; -> 39
+SELECT REGEXP_INSTR('123 123456 1234567, 1234567 1234567 12', '[^ ]+', 1, 6, 1) ;
+-- ORACLE> SELECT REGEXP_INSTR('123 123456 1234567, 1234567 1234567 12', '[^ ]+', 1, 6, 1, 'i') FROM DUAL; -> 39
+SELECT REGEXP_INSTR('123 123456 1234567, 1234567 1234567 12', '[^ ]+', 1, 6, 1, 'i') ;
 
 ----
 -- Tests for REGEXP_SUBSTR()
@@ -265,6 +271,7 @@ SELECT oracle.REGEXP_INSTR('1234', '4', NULL);
 SELECT oracle.REGEXP_INSTR('1234', '4', 1, NULL);
 SELECT oracle.REGEXP_INSTR('1234', '4', 1, 1, NULL);
 SELECT oracle.REGEXP_INSTR('1234', '4', 1, 1, 1, NULL);
+SELECT oracle.REGEXP_INSTR('1234', '4', 1, 1, 1, NULL, 0);
 SELECT oracle.REGEXP_INSTR('1234', '4', 1, 1, 0, NULL);
 SELECT oracle.REGEXP_INSTR('1234', '4', 1, 1, 0, 'i', NULL);
 SELECT oracle.REGEXP_INSTR('1234', '4', 1, 1, 0, '', NULL);
@@ -279,19 +286,30 @@ SELECT oracle.REGEXP_SUBSTR('1234', '234', 1, 1, 'i', null);
 SELECT oracle.REGEXP_SUBSTR('1234', '2(3)(4)', 1, 1, 'i', 1);
 SELECT oracle.REGEXP_SUBSTR('1234', '2(3)(4)', 1, 1, 'i', 2);
 SELECT oracle.REGEXP_SUBSTR('1234', '2(3)(4)', 1, 1, 'i', 0);
--- Special case for second parameter in REGEXP_REPLACE, when null returns the original value.
+
+-- ORACLE> SELECT REGEXP_REPLACE(null, '\d', 'a') FROM DUAL; -> NULL
 SELECT oracle.REGEXP_REPLACE(null, '\d', 'a');
+-- ORACLE> SELECT REGEXP_REPLACE('1234', null, 'a') FROM DUAL; -> 1234
 SELECT oracle.REGEXP_REPLACE('1234', null, 'a');
+-- ORACLE> SELECT REGEXP_REPLACE('1234', null, null) FROM DUAL; -> 1234
 SELECT oracle.REGEXP_REPLACE('1234', null, null);
+-- ORACLE> SELECT REGEXP_REPLACE('1234', '\d', null) FROM DUAL; -> NULL
 SELECT oracle.REGEXP_REPLACE('1234', '\d', null);
+-- ORACLE> SELECT REGEXP_REPLACE('1234', '\d', 'a', null) FROM DUAL; -> NULL
 SELECT oracle.REGEXP_REPLACE('1234', '\d', 'a', null);
+-- ORACLE> SELECT REGEXP_REPLACE('1234', null, 'a', 2) FROM DUAL; -> 1234
 SELECT oracle.REGEXP_REPLACE('1234', null, 'a', 2);
+-- ORACLE> SELECT REGEXP_REPLACE('1234', null, 'a', null) FROM DUAL; -> NULL
 SELECT oracle.REGEXP_REPLACE('1234', null, 'a', null);
+-- ORACLE> SELECT REGEXP_REPLACE('1234', null, 'a', 1) FROM DUAL; -> 1234
 SELECT oracle.REGEXP_REPLACE('1234', null, 'a', 1);
+-- ORACLE> SELECT REGEXP_REPLACE('1234', null, 'a', 1, null) FROM DUAL; -> NULL
 SELECT oracle.REGEXP_REPLACE('1234', null, 'a', 1, null);
+-- ORACLE> SELECT REGEXP_REPLACE('1234', '\d', 'a', 1, null) FROM DUAL; -> NULL
 SELECT oracle.REGEXP_REPLACE('1234', '\d', 'a', 1, null);
-SELECT oracle.REGEXP_REPLACE('1234', '\d', 'a', 1, null);
-SELECT oracle.REGEXP_REPLACE('1234', '\d', 'a', 1, null);
+-- ORACLE> SELECT REGEXP_REPLACE('1234', '\d', 'a', 1, 1, null) FROM DUAL; -> a234
 SELECT oracle.REGEXP_REPLACE('1234', '\d', 'a', 1, 1, null);
+-- ORACLE> SELECT REGEXP_REPLACE('1234', '\d', 'a', 1, NULL, 'i') FROM DUAL; -> NULL
 SELECT oracle.REGEXP_REPLACE('1234', '\d', 'a', 1, NULL, 'i');
+-- ORACLE> SELECT REGEXP_REPLACE('1234', null, 'a', 1, 1, 'i') FROM DUAL; -> 1234
 SELECT oracle.REGEXP_REPLACE('1234', null, 'a', 1, 1, 'i');
